==> rework-0.18.1.tgz: package/lib/plugins/colors.js <==

/**
 * Module dependencies.
 */

var parse = require('color-parser');
var hsb2rgb = require('hsb2rgb');
var functions = require('./function');

/**
 * Provide color manipulation helpers.
 */

module.exports = function() {
  return functions({

    /**
     * Converts RGBA(color, alpha) to the corrosponding RGBA(r, g, b, a) equivalent. 
     *
     *    background: rgba(#eee, .5)
     *    background: rgba(white, .2)
     *
     */

    rgba: function(color, alpha){
      if (2 == arguments.length) {
        var c = parse(color.trim());
        var args = [c.r, c.g, c.b, alpha];
      } else {
        var args = [].slice.call(arguments);
      }

      return 'rgba(' + args.join(', ') + ')';
    },

    /**
     * Converts HSV (HSB) color values to RGB.
     * Saturation and brightness can be expressed as floats or percentages.
     *
     *     color: hsb(220, 45%, .3);
     *     color: hsb(220deg, 0.45, 30%);
     *
     */

    hsb: function (hue, saturation, value) {
      var rgb = hsb2rgb(hue, saturation, value);
      return 'rgb(' + rgb.join(', ') + ')';
    },


    /**
     * Converts HSV (HSB) color values with alpha specified to RGBa.
     * Saturation, brightness and alpha can be expressed as floats or
     * percentages.
     *
     *     color: hsba(220, 45%, .3, .4);
     *     color: hsba(220deg, 0.45, 30%, 40%);
     *
     */

    hsba: function (hue, saturation, value, alpha) {
      alpha = /%/.test(alpha)
        ? parseInt(alpha, 10) / 100
        : parseFloat(alpha, 10);
      
      alpha = String(alpha).replace(/^0+\./, '.');

      var rgb = hsb2rgb(hue, saturation, value);
      return 'rgba(' + rgb.join(', ') + ', ' + alpha + ')';
    }
  });
};

==> rework-0.20.3.tgz: package/lib/plugins/colors.js <==

/**
 * Module dependencies.
 */

var parse = require('color-parser');
var hsb2rgb = require('hsb2rgb');
var functions = require('./function');

/**
 * Provide color manipulation helpers.
 */

module.exports = function() {
  return functions({

    /**
     * Converts RGBA(color, alpha) to the corrosponding RGBA(r, g, b, a) equivalent.
     *
     *    background: rgba(#eee, .5)
     *    background: rgba(white, .2)
     *
     */

    rgba: function(color, alpha){
      var args;
      if (2 == arguments.length) {
        var c = parse(color.trim());
        args = [c.r, c.g, c.b, alpha];
      } else {
        args = [].slice.call(arguments);
      }

      return 'rgba(' + args.join(', ') + ')';
    },

    /**
     * Converts HSV (HSB) color values to RGB.
     * Saturation and brightness can be expressed as floats or percentages.
     *
     *     color: hsb(220, 45%, .3);
     *     color: hsb(220deg, 0.45, 30%);
     *
     */

    hsb: function (hue, saturation, value) {
      var rgb = hsb2rgb(hue, saturation, value);
      return 'rgb(' + rgb.join(', ') + ')';
    },


    /**
     * Converts HSV (HSB) color values with alpha specified to RGBa.
     * Saturation, brightness and alpha can be expressed as floats or
     * percentages.
     *
     *     color: hsba(220, 45%, .3, .4);
     *     color: hsba(220deg, 0.45, 30%, 40%);
     *
     */

    hsba: function (hue, saturation, value, alpha) {
      alpha = /%/.test(alpha)
        ? parseInt(alpha, 10) / 100
        : parseFloat(alpha, 10);

      alpha = String(alpha).replace(/^0+\./, '.');

      var rgb = hsb2rgb(hue, saturation, value);
      return 'rgba(' + rgb.join(', ') + ', ' + alpha + ')';
    }
  });
};
